@@ -1,3 +1,6 @@
+# Copyright 2021 UW-IT, University of Washington
+# SPDX-License-Identifier: Apache-2.0
+
 import json
 import re
 from uw_pws.models import Person
@@ -97,6 +100,10 @@ class SwsPerson(models.Model):
         related_name='permanent_address')
     permanent_phone = models.CharField(max_length=64, null=True, blank=True)
     visa_type = models.CharField(max_length=2, null=True, blank=True)
+    veteran_code = models.CharField(max_length=2)
+
+    def is_veteran(self):
+        return self.veteran_code != "0"
 
     def is_F1(self):
         return self.visa_type is not None and self.visa_type.lower() == 'f1'
@@ -122,13 +129,72 @@ class SwsPerson(models.Model):
             'permanent_address': get_student_address_json(
                 self.permanent_address),
             'permanent_phone': self.permanent_phone,
-            'visa_type': self.visa_type
+            'visa_type': self.visa_type,
+            'veteran_code': self.veteran_code
                 }
 
     def __str__(self):
         return json.dumps(self.json_data())
 
 
+class StudentAdviser(models.Model):
+    is_active = models.BooleanField()
+    is_dept_adviser = models.BooleanField()
+    full_name = models.CharField(max_length=128)
+    pronouns = models.CharField(max_length=140, null=True, blank=True)
+    email_address = models.CharField(max_length=128)
+    phone_number = models.CharField(max_length=32, null=True,
+                                    blank=True, default=None)
+    uwnetid = models.CharField(max_length=32)
+    regid = models.CharField(max_length=32)
+    program = models.CharField(max_length=128, null=True,
+                               blank=True, default=None)
+    booking_url = models.CharField(max_length=128, null=True,
+                                   blank=True, default=None)
+    metadata = models.CharField(max_length=128, null=True, blank=True)
+    timestamp = models.DateField(null=True)
+
+    def __init__(self, *args, **kwargs):
+        data = kwargs.get("data")
+        if data is None:
+            return super(StudentAdviser, self).__init__(*args, **kwargs)
+        self.full_name = data.get("AdvisingFullName")
+        self.email_address = data.get("AdvisingEmailAddress")
+        self.phone_number = data.get("AdvisingPhoneNumber")
+        self.uwnetid = data.get("AdvisingUWNetID")
+        self.regid = data.get("AdvisingRegID")
+        self.program = data.get("AdvisingProgram")
+        self.booking_url = data.get("BookingUrl")
+        self.is_active = data.get("StudentAdvisingIsActive", False)
+        self.is_dept_adviser = data.get("IsDepartmentAdviser", False)
+        self.metadata = data.get("Metadata")
+        self.pronouns = data.get("AdvisingPronouns")
+        self.timestamp = str_to_datetime(data.get("RepositoryTimeStamp"))
+
+    def is_honors_program(self):
+        return self.program == "UW Honors"
+
+    def json_data(self):
+        return {
+            'email_address': self.email_address,
+            'full_name': self.full_name,
+            'pronouns': self.pronouns,
+            'phone_number': self.phone_number,
+            'program': self.program,
+            'uwnetid': self.uwnetid,
+            'regid': self.regid,
+            'booking_url': self.booking_url,
+            'is_active': self.is_active,
+            'is_dept_adviser': self.is_dept_adviser,
+            'is_honors_program': self.is_honors_program(),
+            'metadata': self.metadata,
+            'timestamp': date_to_str(self.timestamp)
+            }
+
+    def __str__(self):
+        return json.dumps(self.json_data())
+
+
 class Term(models.Model):
     SPRING = 'spring'
     SUMMER = 'summer'
